@@ -71,7 +71,7 @@ def assert_sorted(seq: list) -> None:
 def test_comparison() -> None:
     with freeze_time() as frozen_time:
         ulid1 = ULID()
-        assert ulid1 == ulid1
+        assert ulid1 == ulid1  # noqa: PLR0124
         assert ulid1 == int(ulid1)
         assert ulid1 == ulid1.bytes
         assert ulid1 == str(ulid1)
@@ -99,12 +99,23 @@ def test_idempotency() -> None:
     assert ULID.from_uuid(ulid.to_uuid()) == ulid
     assert ULID.from_int(int(ulid)) == ulid
     assert ULID.from_hex(ulid.hex) == ulid
+    assert ULID.parse(ulid) == ulid
+    assert ULID.parse(ulid.to_uuid()) == ulid
+    assert ULID.parse(str(ulid.to_uuid())) == ulid
+    assert ULID.parse(ulid.to_uuid().hex) == ulid
+    assert ULID.parse(str(ulid)) == ulid
+    assert ULID.parse(ulid.hex) == ulid
+    assert ULID.parse(ulid.to_uuid().int) == ulid
+    assert ULID.parse(ulid.milliseconds).milliseconds == ulid.milliseconds
+    assert ULID.parse(ulid.timestamp).timestamp == ulid.timestamp
+    assert ULID.parse(ulid.datetime).datetime == ulid.datetime
+    assert ULID.parse(ulid.bytes) == ulid
 
 
 def test_to_uuid4() -> None:
     ulid = ULID()
     uuid = ulid.to_uuid4()
-    assert uuid.version == 4
+    assert uuid.version == 4  # noqa: PLR2004
 
 
 def test_hash() -> None:
@@ -160,10 +171,12 @@ Params = Union[bytes, str, int, float]
         (ULID.from_str, "Z" * 26),  # invalid timestamp
         (ULID.from_int, "not-an-int"),  # invalid type
         (ULID.from_uuid, "not-a-uuid"),  # invalid type
+        (ULID.parse, "not-a-uuid"),  # invalid length
+        (ULID.parse, []),  # invalid type
     ],
 )
 def test_ulid_invalid_input(constructor: Callable[[Params], ULID], value: Params) -> None:
-    with pytest.raises(ValueError):  # noqa: PT011
+    with pytest.raises((ValueError, TypeError)):
         constructor(value)
 
 
@@ -202,7 +215,7 @@ def test_pydantic_protocol() -> None:
     ulid = ULID()
 
     class Model(BaseModel):
-        ulid: Optional[ULID] = None
+        ulid: Optional[ULID] = None  # noqa: FA100
 
     for value in [ulid, str(ulid), int(ulid), bytes(ulid)]:
         model = Model(ulid=value)
